import { Button, Space, Modal, FormInstance, Form, Select } from "antd";
import { inject, observer } from "mobx-react";
import type { ColumnsType } from "antd/es/table";
import BTable from "@/components/b_table";
import { useEffect, useState } from "react";
import { UserDataType } from "@/model/userModel";
import { Store } from "antd/lib/form/interface";
import SimpleForm from "@/components/form/simple_form";
import React from "react";
import { FormType } from "@/components/form/interface";
const { Option } = Select;
const Dep = (props: Store) => {
  const { depStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const formRef = React.useRef<FormInstance>(null);
  const [record, setRecord] = useState<any>(null);
  const [tagId, setId] = useState<Number | null>(null);
  const columns: ColumnsType<UserDataType> = [
    { title: "部门名称", dataIndex: "dep_name" },
    { title: "部门描述", dataIndex: "remark" },
    {
      title: "操作",
      dataIndex: "id",
      render: (any, record) => (
        <div>
          <Space wrap>
            <Button
              type="dashed"
              size="small"
              onClick={() => {
                edit(record);
              }}
            >
              编辑
            </Button>
            <Button
              type="dashed"
              danger
              size="small"
              onClick={() => {
                depStore.deleteItem(record.id);
              }}
            >
              删除
            </Button>
          </Space>
        </div>
      ),
    },
  ];
  const edit = (record) => {
    let data = {
      ...record,
      head_img: [{ url: record.head_img }],
    };
    setProjectConfig(defaultConfig);
    setIsModalOpen(true);
    formRef.current?.setFieldsValue(data);
    setRecord(data);
    setId(record.id);
  };
  const onFinish = (values: any) => {
    if (!tagId) {
      depStore.add(values);
    } else {
      depStore.putItem(tagId, values);
    }
    setIsModalOpen(false);
  };
  useEffect(() => {
    depStore.getlist();
  }, [depStore]);
  const defaultConfig = [
    {
      type: "input",
      label: "部门名称",
      name: "dep_name",
      value: "",
      rules: [{ required: true, message: "请输入部门名称!" }],
    },
    {
      type: "input",
      label: "部门描述",
      name: "remark",
      value: "",
      rules: [{ required: true, message: "请输入部门描述" }],
    },
    {
      type: FormType.radio,
      label: "第三方机构",
      name: "other",
      radioData: [
        {
          key: "是",
          val: 1,
        },
        {
          key: "否",
          val: 2,
        },
      ],
      value: "",
      rules: [{ required: true, message: "请输入部门描述" }],
    },
  ];
  const onFinishFailed = () => {};
  return (
    <div className="contentBox">
      <Space direction="vertical" size="middle" style={{ display: "flex" }}>
        <Space direction="horizontal" size={"middle"}>
          <Button
            type="default"
            onClick={() => {
              setProjectConfig(defaultConfig);
              setId(null);
              setIsModalOpen(true);
            }}
          >
            添加
          </Button>
        </Space>

        <BTable store={depStore} columns={columns} dataSource={depStore.list} />
        <Modal
          title={!tagId ? "添加部门" : "编辑部门"}
          width={800}
          open={isModalOpen}
          afterClose={() => formRef.current?.resetFields()}
          onOk={() => formRef.current?.submit()}
          okText="确定"
          cancelText="取消"
          onCancel={() => {
            setId(null);
            setIsModalOpen(false);
          }}
        >
          <SimpleForm
            formRef={formRef}
            createCallback={() => {
              formRef.current?.setFieldsValue(record);
            }}
            formName="card_basic"
            colProps={25}
            subBtnName="提交"
            formDatas={projectConfig}
            onFinish={onFinish}
            initialValues={true}
            onFinishFailed={onFinishFailed}
          >
            <>
              <Form.Item key="pdep_id" label="上级部门" name="pdep_id">
                <Select placeholder="">
                  {depStore.list?.map((v: any) => {
                    return (
                      <Option key={v.id} value={v.id}>
                        {v.dep_name}
                      </Option>
                    );
                  })}
                </Select>
              </Form.Item>
            </>
          </SimpleForm>
        </Modal>
      </Space>
    </div>
  );
};

export default inject("depStore")(observer(Dep));
